@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -88,6 +88,8 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                 button.set_property("menu-name", widget.submenu_name)
                 button.show()
                 parent = self.__grids["main"]
+                if widget.section is not None:
+                    self.__add_section(widget.section, "main")
                 widget = button
             else:
                 parent = self.get_child_by_name("main")
@@ -196,7 +198,8 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                 submenu = menu.get_item_link(i, "submenu")
                 if link is not None:
                     self.__menu_queue.append((menu, menu_name, indexes))
-                    self.__add_section(label, link, menu_name)
+                    self.__add_section(label, menu_name)
+                    self.__add_menu(link, menu_name, False, False)
                 elif submenu is not None:
                     self.__add_submenu(label, submenu, menu_name)
                     GLib.idle_add(self.__add_menu_items, menu,
@@ -244,11 +247,10 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         button.show()
         self.__grids[menu_name].add(button)
 
-    def __add_section(self, text, menu, menu_name):
+    def __add_section(self, text, menu_name):
         """
             Add section to menu
             @param text as as GLib.Variant
-            @param menu as Gio.Menu
             @param menu_name as str
         """
         box = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 4)
@@ -267,7 +269,6 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         box.add(sep2)
         box.show_all()
         self.__grids[menu_name].add(box)
-        self.__add_menu(menu, menu_name, False, False)
 
     def __add_submenu(self, text, menu, menu_name):
         """
@@ -407,11 +408,9 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                     pixbuf.scale_simple(ArtSize.MEDIUM, ArtSize.MEDIUM,
                                         GdkPixbuf.InterpType.BILINEAR),
                     scale_factor, None)
-                del pixbuf
                 rounded = get_round_surface(surface, scale_factor,
                                             ArtSize.MEDIUM / 4)
                 artwork.set_from_surface(rounded)
-                del rounded
                 artwork.show()
         button = Gtk.ModelButton.new()
         button.set_hexpand(True)
@@ -434,7 +433,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         button.set_image(grid)
         button.get_style_context().add_class("padding")
         App().task_helper.run(
-                App().art.get_artwork_from_cache,
+                App().art.get_from_cache,
                 artwork_name,
                 "ROUNDED",
                 ArtSize.BANNER, ArtSize.BANNER,
